/*
    Copyright (C) 2000 Paul Davis 

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

    $Id: overlap.h,v 1.4 2003/10/29 04:27:23 pbd Exp $
*/

#ifndef __ardour_overlap_h__
#define __ardour_overlap_h__

#include <sigc++/signal_system.h>
#include <ardour/ardour.h>

namespace ARDOUR {

class AudioRegion;

class Overlap : public SigC::Object 
{
  public:
	ARDOUR::AudioRegion *right;
	ARDOUR::AudioRegion *left;
	
	Overlap (ARDOUR::AudioRegion *r, ARDOUR::AudioRegion *l);
	virtual ~Overlap();

	void update();
	bool involves (ARDOUR::AudioRegion *region) const {
		return right == region || left == region;
	}

	jack_nframes_t length() const;

	SigC::Signal0<void> Changed;
	SigC::Signal0<void> GoingAway;

	struct Compare {
	    bool operator() (const Overlap a, const Overlap b) const;
	};

	struct ComparePtr {
	    bool operator() (const Overlap *a, const Overlap *b) const;
	};

  private:
	jack_nframes_t last_length;
};


} // namespace ARDOUR

#endif /* __ardour_overlap_h__ */	
